"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const utils_1 = require("@morjs/utils");
const path_1 = tslib_1.__importDefault(require("path"));
const scriptTransformer_1 = require("../transformers/scriptTransformer");
const utils_2 = require("../utils");
async function SjsLoader(fileContent) {
    const cb = this.async();
    const options = this.getOptions();
    const { userConfig, entryBuilder, runner } = options;
    const entry = entryBuilder.getEntryByFilePath(this.resourcePath);
    let code;
    let sourceMap;
    const parserInfo = {
        userConfig,
        loaderContext: this,
        fileInfo: {
            path: this.resourcePath,
            content: fileContent,
            extname: entry ? entry.extname : path_1.default.extname(this.resourcePath),
            entryName: entry ? entry.fullEntryName : undefined,
            entryFileType: entry ? entry.entryFileType : undefined,
            entryType: entry ? entry.entryType : utils_1.EntryType.unknown
        }
    };
    // sjs 插件支持
    let transformers;
    if ((0, utils_2.shouldProcessFileByPlugins)(this.resourcePath, userConfig.processNodeModules, options.processNodeModules) &&
        runner.hooks.sjsParser.isUsed()) {
        transformers = runner.hooks.sjsParser.call({
            before: [],
            after: [],
            afterDeclarations: []
        }, parserInfo);
    }
    try {
        const res = await (0, scriptTransformer_1.scriptTransformer)(fileContent, utils_1.EntryFileType.sjs, parserInfo, transformers);
        code = res.code;
        sourceMap = res.sourceMap;
    }
    catch (error) {
        return cb(error);
    }
    const res = (0, scriptTransformer_1.generateSourceMap)(sourceMap, code, this.resourcePath, fileContent, this.remainingRequest);
    cb(null, res.code, res.sourceMap);
}
exports.default = SjsLoader;
//# sourceMappingURL=sjsLoader.js.map